Check if INLA is installed and meets the minimum version requirement
Source:R/utils.R
check_inla.RdChecks whether the INLA package is installed and whether the installed version is >= 23.4.24. This is an internal utility used by functions that depend on INLA.