| check_inla | R Documentation |
Checks whether the INLA package is installed and whether the installed version is >= 23.4.24. This is an internal utility used by functions that depend on INLA.
check_inla(error = FALSE)
error |
Logical. If |
TRUE if INLA is installed and meets the version requirement, FALSE otherwise (when error = FALSE).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.