| london | R Documentation |
The dataset includes observed daily mean temperature and total number of deaths in London between 2000 and 2011. Mortality data is stratified for <75 years and 75+ years age groups. The dataset is based on the data used in Vicedo-Cabrera et al. (2019).
data(london)
londonA tibble with 8.279 rows and 7 columns:
Date index
Date
Year
Day of the week
Temperature mean
Mortality in the age group <75 years
Mortality in the age group +75 years
All mortality
Data originally published by Vicedo-Cabrera (2019) doi:10.1097/EDE.0000000000000982.
Vicedo-Cabrera A.M., Sera F., Gasparrini A. (2019). Hands-on tutorial on a modeling framework for projections of climate change impacts on health. Epidemiology, 30(3), 321-329. doi:10.1097/EDE.0000000000000982.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.